Method: Azeroth::Options#after_save
- Defined in:
- lib/azeroth/options.rb
#after_save ⇒ Symbol, Proc
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Block or method name to be run after save
The given method or block will be ran after committing changes in models to database
|
|
# File 'lib/azeroth/options.rb', line 107
|